==> statistics-0.6.1.module.tgz: modules/statistics/module.inc.php <==
<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@version	CVS: $Id: module.inc.php,v 1.1.1.1 2006/02/20 21:52:22 xiam Exp $
	*	@link		http://www.gekkoware.org
	*/


	if (!defined("IN-GEKKO")) die("Get a life!");

	Class GekkoModule_Statistics {
		function create_menu() {
			return false;
		}
		function configure() {

		}
		function install() {

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_counter")." (
				type VARCHAR (32),
				variable VARCHAR (64),
				counter SMALLINT (5)
			)
			",__FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_day")." (
				day DATE NOT NULL,

				h00 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h01 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h02 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h03 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h04 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h05 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h06 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h07 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h08 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h09 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h10 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h11 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h12 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h13 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h14 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h15 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h16 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h17 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h18 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h19 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h20 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h21 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h22 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h23 SMALLINT (5) UNSIGNED NOT NULL default '0',

				total MEDIUMINT (8) UNSIGNED NOT NULL DEFAULT '0',
				variant TINYINT (1) UNSIGNED default '0'
			)
			");

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_visits")." (
				day DATE NOT NULL,
				uniquehits MEDIUMINT (8) UNSIGNED NOT NULL default '0',
				total MEDIUMINT (8) UNSIGNED NOT NULL default '0'
			)
			",__FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_uri_logs")." (
				type VARCHAR (32),
				url VARCHAR (255),
				counter SMALLINT (5),
				lastip VARCHAR (32),
				lasttime INT (11) UNSIGNED NOT NULL
			)
			",__FILE__, __LINE__, true);

			modCore::registerModule($GLOBALS["cgdb"]["statistics"], "statistics", "#", $GLOBALS["cgdb"]["statistics"]);
		}
		function uninstall() {
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_counter"),__FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_visits"),__FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_day"),__FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_uri_logs"),__FILE__, __LINE__, true);
		}
		function upgrade($provided_v) {
			$db =& $GLOBALS["db"];

			if (Packages::checkVersion("0.5.7", $provided_v) < 0) {
				// creating recently introduced table
				$q = $db->query("
				CREATE TABLE ".db_table("stats_day")." (
					day DATE NOT NULL,

					h00 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h01 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h02 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h03 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h04 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h05 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h06 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h07 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h08 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h09 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h10 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h11 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h12 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h13 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h14 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h15 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h16 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h17 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h18 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h19 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h20 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h21 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h22 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h23 SMALLINT (5) UNSIGNED NOT NULL default '0',

					total MEDIUMINT (8) UNSIGNED NOT NULL default '0',
					variant TINYINT (1) UNSIGNED NOT NULL default '0'
				)",
				__FILE__, __LINE__, true);

				// altering table (stage 1)
				$q = $db->query ("ALTER TABLE ".db_table("stats_visits")."
					ADD day_temp DATE NOT NULL AFTER day,
					CHANGE total uniquehits MEDIUMINT (8) UNSIGNED NOT NULL default '0',
					ADD total MEDIUMINT (8) UNSIGNED NOT NULL default '0'
				", __FILE__, __LINE__, true);

				// copying uniquehits to total
				$p = $db->query("UPDATE ".db_table("stats_visits")." SET total = uniquehits",
				__FILE__, __LINE__, true);

				// moving data to new table
				$q = $db->query("SELECT year, month, day, h00, h01, h02, h03, h04, h05, h06, h07, h08,
				h09, h10, h11, h12, h13, h14, h15, h16, h17, h18, h19, h20, h21, h22, h23, total
				FROM ".db_table("stats_visits")."",
				__FILE__, __LINE__, true);

				while ($row = $db->fetch_row($q)) {

					// converting date
					$day = implode("-", array($row["year"], $row["month"], $row["day"]));

					$p = $db->query("UPDATE ".db_table("stats_visits")." SET day_temp = '$day'
					WHERE year='{$row["year"]}' AND month='{$row["month"]}' AND day='{$row["day"]}'",
					__FILE__, __LINE__, true);

					unset ($row["year"], $row["month"], $row["day"]);

					$fields = $values = Array();
					foreach ($row as $field => $value) {
						$fields[] = $field;
						$values[] = $value;
					}
					$fields = implode(", ", $fields);
					$values = implode(", ", $values);
					$p = $db->query("INSERT INTO ".db_table("stats_day")." (day, $fields, variant) VALUES ('$day', $values, 0)",
					__FILE__, __LINE__, true);

				}

				// altering table (stage 2)
				// now that we've moved data from our old table format, we're going to alter
				// our visitors table to match this version's
				$q = $db->query("ALTER TABLE ".db_table("stats_visits")."
					DROP h00, DROP h01, DROP h02, DROP h03, DROP h04, DROP h05, DROP h06, DROP h07,
					DROP h08, DROP h09, DROP h10, DROP h11, DROP h12, DROP h13, DROP h14, DROP h15,
					DROP h16, DROP h17, DROP h18, DROP h19, DROP h20, DROP h21, DROP h22, DROP h23,
					DROP year, DROP month, DROP day, CHANGE day_temp day DATE NOT NULL
				", __FILE__, __LINE__, true);
			}
		}
		function ext_uninstall($module) {

		}
	}

?>

==> statistics-0.7.module.tgz: modules/statistics/module.inc.php <==
<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@link		http://www.gekkoware.org
	*/


	if (!defined("IN-GEKKO")) die("Get a life!");

	Class gekkoModule_Statistics {
		function create_menu() {
			return false;
		}
		function configure() {

		}
		function install() {

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_counter")." (
				type VARCHAR (32),
				variable VARCHAR (64),
				counter SMALLINT (5)
			)
			",__FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_day")." (
				day DATE NOT NULL,

				h00 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h01 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h02 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h03 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h04 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h05 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h06 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h07 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h08 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h09 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h10 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h11 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h12 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h13 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h14 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h15 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h16 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h17 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h18 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h19 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h20 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h21 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h22 SMALLINT (5) UNSIGNED NOT NULL default '0',
				h23 SMALLINT (5) UNSIGNED NOT NULL default '0',

				total MEDIUMINT (8) UNSIGNED NOT NULL DEFAULT '0',
				variant TINYINT (1) UNSIGNED default '0'
			)
			");

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_visits")." (
				day DATE NOT NULL,
				uniquehits MEDIUMINT (8) UNSIGNED NOT NULL default '0',
				total MEDIUMINT (8) UNSIGNED NOT NULL default '0'
			)
			",__FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
			CREATE TABLE ".db_table("stats_uri_logs")." (
				type VARCHAR (32),
				url VARCHAR (255),
				counter SMALLINT (5),
				last_ip VARCHAR (64),
				date_access TIMESTAMP(19)
			)
			",__FILE__, __LINE__, true);

			$GLOBALS["db"]->query("
				CREATE TABLE ".db_table("stats_search_keywords")." (
					keywords VARCHAR (255),
					engine VARCHAR (255),
					counter MEDIUMINT (8) UNSIGNED NOT NULL,
					url VARCHAR (255),
					referer VARCHAR (255),
					date_access TIMESTAMP(19)
				)
			", __FILE__, __LINE__, true);

			gekkoModule::register($GLOBALS["cgdb"]["statistics"], "statistics", "#", $GLOBALS["cgdb"]["statistics"]);
		}
		function uninstall() {
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_counter"),__FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_visits"),__FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_day"),__FILE__, __LINE__, true);
			$GLOBALS["db"]->query("DROP TABLE IF EXISTS ".db_table("stats_uri_logs"),__FILE__, __LINE__, true);
		}
		function upgrade($provided_v) {
			$db =& $GLOBALS["db"];

			if (Packages::checkVersion("0.5.7", $provided_v) < 0) {
				// creating recently introduced table
				$q = $db->query("
				CREATE TABLE ".db_table("stats_day")." (
					day DATE NOT NULL,

					h00 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h01 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h02 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h03 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h04 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h05 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h06 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h07 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h08 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h09 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h10 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h11 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h12 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h13 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h14 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h15 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h16 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h17 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h18 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h19 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h20 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h21 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h22 SMALLINT (5) UNSIGNED NOT NULL default '0',
					h23 SMALLINT (5) UNSIGNED NOT NULL default '0',

					total MEDIUMINT (8) UNSIGNED NOT NULL default '0',
					variant TINYINT (1) UNSIGNED NOT NULL default '0'
				)",
				__FILE__, __LINE__, true);

				// altering table (stage 1)
				$q = $db->query ("ALTER TABLE ".db_table("stats_visits")."
					ADD day_temp DATE NOT NULL AFTER day,
					CHANGE total uniquehits MEDIUMINT (8) UNSIGNED NOT NULL default '0',
					ADD total MEDIUMINT (8) UNSIGNED NOT NULL default '0'
				", __FILE__, __LINE__, true);

				// copying uniquehits to total
				$p = $db->query("UPDATE ".db_table("stats_visits")." SET total = uniquehits",
				__FILE__, __LINE__, true);

				// moving data to new table
				$q = $db->query("SELECT year, month, day, h00, h01, h02, h03, h04, h05, h06, h07, h08,
				h09, h10, h11, h12, h13, h14, h15, h16, h17, h18, h19, h20, h21, h22, h23, total
				FROM ".db_table("stats_visits")."",
				__FILE__, __LINE__, true);

				while ($row = $db->fetchRow($q)) {

					// converting date
					$day = implode("-", array($row["year"], $row["month"], $row["day"]));

					$p = $db->query("UPDATE ".db_table("stats_visits")." SET day_temp = '$day'
					WHERE year='{$row["year"]}' AND month='{$row["month"]}' AND day='{$row["day"]}'",
					__FILE__, __LINE__, true);

					unset ($row["year"], $row["month"], $row["day"]);

					$fields = $values = Array();
					foreach ($row as $field => $value) {
						$fields[] = $field;
						$values[] = $value;
					}
					$fields = implode(", ", $fields);
					$values = implode(", ", $values);
					$p = $db->query("INSERT INTO ".db_table("stats_day")." (day, $fields, variant) VALUES ('$day', $values, 0)",
					__FILE__, __LINE__, true);

				}

				// altering table (stage 2)
				// now that we've moved data from our old table format, we're going to alter
				// our visitors table to match this version's
				$q = $db->query("ALTER TABLE ".db_table("stats_visits")."
					DROP h00, DROP h01, DROP h02, DROP h03, DROP h04, DROP h05, DROP h06, DROP h07,
					DROP h08, DROP h09, DROP h10, DROP h11, DROP h12, DROP h13, DROP h14, DROP h15,
					DROP h16, DROP h17, DROP h18, DROP h19, DROP h20, DROP h21, DROP h22, DROP h23,
					DROP year, DROP month, DROP day, CHANGE day_temp day DATE NOT NULL
				", __FILE__, __LINE__, true);
			}

			if (packages::checkVersion("0.6.2", $provided_v) < 0) {

				$db->query("
					CREATE TABLE ".db_table("stats_search_keywords")." (
						keywords VARCHAR (255),
						engine VARCHAR (255),
						counter MEDIUMINT (8) UNSIGNED NOT NULL,
						url VARCHAR (255),
						referer VARCHAR (255),
						date_access TIMESTAMP(19)
					)
				", __FILE__, __LINE__, true);

				$db->query("ALTER TABLE ".db_table("stats_uri_logs")."
				CHANGE COLUMN lastip last_ip VARCHAR (64),
				ADD COLUMN date_access TIMESTAMP(19) AFTER lasttime",
				__FILE__, __LINE__, true);

				$db->query("UPDATE ".db_table("stats_uri_logs")."
				SET date_access = FROM_UNIXTIME(lasttime)",
				__FILE__, __LINE__, true);

				$db->query("ALTER TABLE ".db_table("stats_uri_logs")." DROP COLUMN lasttime",
				__FILE__, __LINE__, true);
			}

		}
		function ext_uninstall($module) {

		}
	}

?>
